==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MealyStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;

import java.util.Arrays;
import java.util.List;


public class MealyStateMachineSetImpl extends InstanceSet<MealyStateMachineSet,MealyStateMachine> implements MealyStateMachineSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MealyStateMachine mealystatemachine : this ) mealystatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R510_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( MealyStateMachine mealystatemachine : this ) sm_smset.add( mealystatemachine.R510_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public MealyActionHomeSet R512_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( MealyStateMachine mealystatemachine : this ) mealyactionhomeset.addAll( mealystatemachine.R512_MealyActionHome() );
        return mealyactionhomeset;
    }


    @Override
    public MealyStateMachine nullElement() {
        return MealyStateMachineImpl.EMPTY_MEALYSTATEMACHINE;
    }

    @Override
    public MealyStateMachineSet emptySet() {
      return new MealyStateMachineSetImpl();
    }

    @Override
    public MealyStateMachineSet value() {
        return this;
    }

    @Override
    public List<MealyStateMachine> elements() {
        return Arrays.asList(toArray(new MealyStateMachine[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MealyStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.MealyStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MealyActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class MealyStateMachineSetImpl extends InstanceSet<MealyStateMachineSet,MealyStateMachine> implements MealyStateMachineSet {

    public MealyStateMachineSetImpl() {
    }

    public MealyStateMachineSetImpl(Comparator<? super MealyStateMachine> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MealyStateMachine mealystatemachine : this ) mealystatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R510_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( MealyStateMachine mealystatemachine : this ) sm_smset.add( mealystatemachine.R510_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public MealyActionHomeSet R512_MealyActionHome() throws XtumlException {
        MealyActionHomeSet mealyactionhomeset = new MealyActionHomeSetImpl();
        for ( MealyStateMachine mealystatemachine : this ) mealyactionhomeset.addAll( mealystatemachine.R512_MealyActionHome() );
        return mealyactionhomeset;
    }


    @Override
    public MealyStateMachine nullElement() {
        return MealyStateMachineImpl.EMPTY_MEALYSTATEMACHINE;
    }

    @Override
    public MealyStateMachineSet emptySet() {
      return new MealyStateMachineSetImpl();
    }

    @Override
    public MealyStateMachineSet emptySet(Comparator<? super MealyStateMachine> comp) {
      return new MealyStateMachineSetImpl(comp);
    }

    @Override
    public MealyStateMachineSet value() {
        return this;
    }

    @Override
    public List<MealyStateMachine> elements() {
        return Arrays.asList(toArray(new MealyStateMachine[0]));
    }

}
